/* ------------------------------------------------------------- */
/* - STM32 I2C LCD module controller                             */
/*                                  released by fumi2kick        */
/*                                  http://www.fumi2kick.com/    */
/*                                  rerofumi <rero2@yuumu.org>   */
/* ------------------------------------------------------------- */
/* update                                                        */
/*   Mar.20.2011 : first release                                 */
/* ------------------------------------------------------------- */
/* memo                                                          */
/*                                                               */
/* ------------------------------------------------------------- */

/* ----------------------------------- */
/* --- include                         */
/* ----------------------------------- */

#include "stm32f10x_i2c.h"

/* ----------------------------------- */
/* --- define                          */
/* ----------------------------------- */

/* I2C1 or I2C2 */
#define FM_I2CLCD_I2CPORT_1  0
#define FM_I2CLCD_I2CPORT_2  1

/* slave address */
#define FM_I2CLCD_ADDRESS 0x3e

/* reset pin config */
#define FM_I2CLCD_SW_USERESET  1
#define FM_I2CLCD_RESETPORT    GPIOB
#define FM_I2CLCD_RESETPIN     0x1000

/* I2CLCD task state */
enum {
  STATE_I2CLCD_NULL = 0,
  STATE_I2CLCD_NONE_INITALIZE,
  STATE_I2CLCD_INITALIZING,
  STATE_I2CLCD_READY,
  STATE_I2CLCD_WORKING,
  STATE_I2CLCD_ERROR,
  STATE_I2CLCD_SUSPEND,
} FM_I2CLCD_STATE;


/* ----------------------------------- */
/* --- prototyping                     */
/* ----------------------------------- */

/**
 * I2C peripheral initialize
 * @param port [in] I2C port select (0 or 1)
 * @return result (0=success)
 */
extern int fmI2C_Init(int port);

/**
 * I2C LCD initialize and polling
 * FreeRTOS task routine
 * @param pcParam [in] from task manager
 */
extern void vI2C_LCD_TASK(void *pcParam);

/**
 * LCD Display driver statement
 * @return I2CLCD task status (FM_I2CLCD_STATE)
 */
extern int fmI2C_LCD_State(void);

/**
 * display clear
 */
extern void fmI2C_LCD_ClearScreen(void);

/**
 * display contrast
 * @param cont [in] cotrast value (0-255)
 */
extern void fmI2C_LCD_Contrast(int cont);

/**
 * move display position
 * @param x,y [in] position
 */
extern void fmI2C_LCD_Position(int x, int y);

/**
 * display 1 byte code
 * @param cCode [in] display char
 */
extern void fmI2C_LCD_PutChar(const unsigned char cCode);

/**
 * display string
 * @param cString [in] display string
 * @param size [in] cString max size (fail safe)
 */
extern void fmI2C_LCD_Puts(const unsigned char *cString, const int size);

/**
 * display hex
 * @param val [in] display value
 */
extern void fmI2C_LCD_DisplayHex_8(const uint8_t val);
extern void fmI2C_LCD_DisplayHex_16(const uint16_t val);
extern void fmI2C_LCD_DisplayHex_32(const uint32_t val);


/* ----------------------------------- */
/* --- IRQ handler call                */
/* ----------------------------------- */

/**
 * I2C event handler
 */
extern void fmI2C_IRQ_EV(void);

/**
 * I2C error handler
 */
extern void fmI2C_IRQ_ER(void);
